@@ -23,6 +23,8 @@ set SSHCommand "ssh"
 # Command to run md-mx-ctrl
 set MD_MX_CTRL "md-mx-ctrl -i"
 
+set DoArchive 0
+
 if {[info exists env(MD_MX_CTRL)]} {
     set x $env(MD_MX_CTRL)
     if {"$x" != ""} {
@@ -30,6 +32,10 @@ if {[info exists env(MD_MX_CTRL)]} {
     }
 }
 
+proc strip_zeros { num } {
+    return [regsub {\.0+$} $num ""]
+}
+
 # Don't edit anything below here!
 set Machines {}
 set ctr 0
@@ -111,6 +117,7 @@ proc open_connection { mach } {
 }
 
 proc connection_readable { mach fp } {
+    global DoArchive
     gets $fp line
     if {"$line" == ""} {
 	if {[eof $fp]} {
@@ -122,9 +129,25 @@ proc connection_readable { mach fp } {
     set index [find_machine $mach]
     if {$index >= 0} {
 	catch { update_machine $line $index $mach }
+	if {$DoArchive} {
+	    if {[catch { log_stats $mach $line } err]} {
+		puts stderr $err
+	    }
+	}
+
     }
 }
 
+proc log_stats { mach line } {
+    set dir "~/.watch-multiple-mimedefangs/$mach"
+    if {![file isdirectory $dir]} {
+	file mkdir $dir
+    }
+    set fp [open "$dir/data" "a"]
+    puts $fp "[clock seconds] $line"
+    close $fp
+}
+
 proc mach_set_status_error { mach index err } {
     global Data
     set Data($mach,error) 1
@@ -209,10 +232,9 @@ proc redraw {} {
 	set Data($mach,time) [graph [expr 2.0/3] 1 0 auto $Data($mach,time) $index "ms/scan" 3 blue 1]
 	incr index
     }
-    set hour [expr $persec_total * 3600.0]
-    set day  [expr $persec_total * 86400.0]
-    set hour [format "%.0f" $hour]
-    set day [format "%.0f" $day]
+    set hour [human_number [expr $persec_total * 3600.0]]
+    set day  [human_number [expr $persec_total * 86400.0]]
+    set persec_total [strip_zeros [format "%.1f" $persec_total]]
     .top.c configure -text "Total throughput $persec_total/s = $hour/hour = $day/day"
     update
 }
@@ -596,17 +618,20 @@ proc nicenum {x floor} {
 
 proc human_number { num } {
     if {$num <= 1000} {
-	return $num
+	return [strip_zeros [format "%.1f" $num]]
     }
     set num [expr $num / 1000.0]
     if {$num <= 1000} {
+	set num [strip_zeros [format "%.1f" $num]]
 	return "${num}K"
     }
     set num [expr $num / 1000.0]
     if {$num <= 1000} {
+	set num [strip_zeros [format "%.1f" $num]]
 	return "${num}M"
     }
     set num [expr $num / 1000.0]
+    set num [strip_zeros [format "%.1f" $num]]
     return "${num}G"
 }
 
@@ -645,6 +670,10 @@ proc ssh { host {cmd ""} {title ""}} {
 
 wm withdraw .
 foreach mach $argv {
+    if {"$mach" == "-archive"} {
+	set DoArchive 1
+	continue
+    }
     add_machine $mach
 }
 
